/*
 YamCha -- Yet Another Multipurpose CHunk Annotator

 $Id: param_open.cpp,v 1.5 2002/11/11 10:12:16 taku-ku Exp $;

 Copyright (C) 2001-2002  Taku Kudo <taku-ku@is.aist-nara.ac.jp>
 All rights reserved.

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later verjsion.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the
 Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <iostream>
#include <fstream>
#include "param.h"
#include "common.h"

#define YAMCHA_HELP "Usage: yamcha [optsions] <files>...\n\
\n\
Parser Mode:\n\
  -m, --model=FILE           use FILE as model file.\n\
  -C, --candidate            estimate tags from the given candidates.\n\
  -V, --verbose              verbose mode,\n\
                             print tags and scores of all candidates.\n\
  -e, --eos-string=STR       set EOS marker to STR.\n\
\n\
Training Mode:\n\
  -F, --feature=PATTERN      set PATTERN for the feature representation.\n\
  -B, --backward             select features from the end of sentence.\n\
\n\
Miscellaneous:\n\
  -o, --output=FILE          set the output file name to FILE.\n\
  -v, --version              show the version of YamCha and exit.\n\
  -h, --help                 show this help and exit.\n\
"

namespace YamCha {

  static const Option long_options[] = 
  {
    {"model",          'm', 1},
    {"candidate",      'C', 0},
    {"verbose",        'V', 0},
    {"feature",        'F', 1},
    {"backward",       'B', 0},
    {"output",         'o', 1},
    {"eos-string" ,    'e', 1},
    {"version",        'v', 0},
    {"help",           'h', 0},
    {0,0,0}
  };

  bool Param::open (int argc, char **argv)
  {
    opts = const_cast<Option *>(long_options);

    clear ();

    if (! this->getopt (argc, argv)) {
      _what += std::string ("\n\n") +  std::string (COPYRIGHT) + "\ntry '--help' for more information.\n" ;
      return false;
    }

    if (getProfileInt ("help")) {
      if (os) {
	 *os << COPYRIGHT << YAMCHA_HELP << std::endl;
	 exit (EXIT_SUCCESS);
      } else {
	 _what = std::string (COPYRIGHT) + YAMCHA_HELP;
	 return false;
      }
    }
	
    if (getProfileInt ("version")) {
      if (os) {
	 *os << PACKAGE << " of " << VERSION << std::endl;
	 exit (EXIT_SUCCESS);
      } else {
	 _what = std::string (PACKAGE) + std::string (" of ") + std::string (VERSION);
	 return false; 
      }
    }

    return true;       
  }
}
