/*
 YamCha -- Yet Another Multipurpose CHunk Annotator

 $Id: yamcha.cpp,v 1.6 2002/10/21 16:33:14 taku-ku Exp $;

 Copyright (C) 2001  Taku Kudoh <taku-ku.aist-nara.ac.jp>
 All rights reserved.

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later verjsion.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the
 Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.
*/
#include <string>
#include <iostream>
#include <fstream>
#include <stdexcept>
#include <cstdlib>
#include "param.h"
#include "yamcha.h"
#include "common.h"

int main (int argc, char **argv) 
{
  using namespace std;

  try {

    YamCha::Param param;
    param.setHelpStream (std::cout);

    if (! param.open (argc, argv)) throw std::runtime_error (param.what());

    YamCha::Chunker chunker;
    if (! chunker.open (param)) throw std::runtime_error (chunker.what());

    std::ostream *ofs = &std::cout;

    std::string output = param.getProfileString ("output");

    if (output != "") {
      ofs = new std::ofstream (output.c_str());
      if (! *ofs) {
	std::cerr << argv[0] << ": " << output << ": permission denied" << std::endl;
	exit (EXIT_FAILURE);
      }
    } 

    std::vector <std::string> rest = param.getRestArg ();

    if (rest.size()) {
      for (unsigned int i = 0; i < rest.size(); i++) {
	std::ifstream ifs (rest[i].c_str());
	if (! ifs) {
	  std::cerr << argv[0] << ": " << rest[i] << ": no such file or directory" << std::endl;
	  continue;
	}
	while (chunker.parse (ifs, *ofs)) {};
      }
    } else {
      while (chunker.parse (std::cin, *ofs)) {};
    }

    if (ofs != &std::cout) delete ofs;
    exit (EXIT_SUCCESS);
  } 


  catch (std::exception &e) {
    std::cout << e.what() << std::endl  << std::endl <<  COPYRIGHT << std::endl
	 << "`" << PACKAGE << " --help' for more information." << std::endl;
    exit(EXIT_FAILURE);
  }
}
